@@ -12,7 +12,7 @@
 #' axis
 #' @param minimum_faces Minimum number of ply faces required
 #' for a patch to be counted towards the total patch count
-#' @param minimum_area Minimual percentage of total surface area a
+#' @param minimum_area Minimum proportion (100%=1.0) of total surface area a
 #' patch must occupy to be counted towards the total patch count
 #' 
 #' @details The function requires a mesh object created by reading in a ply file utilizing
@@ -34,7 +34,7 @@
 #' OPC
 #'
 #' @examples
-#' OPC_output <- OPC(ex_tooth1)
+#' OPC_output <- OPC(Tooth)
 #' summary(OPC_output)
 
 
@@ -57,12 +57,12 @@ OPC <- function(plyFile, rotation=0, minimum_faces=3, minimum_area=0) {
   binned_patches <- patches_for_each_direction(indexed_pairs)
   
   ### Pull Details of Each Patch ###
-  patch_details <- patch_details(binned_patches, plyFile)
+  patch_details. <- patch_details(binned_patches, plyFile)
   
   ### Patch Counting ###
   minimum_faces <- minimum_faces
   minimum_area <- minimum_area
-  patch_count <- patches_per(patch_details, plyFile, minimum_faces, minimum_area)
+  patch_count <- patches_per(patch_details., plyFile, minimum_faces, minimum_area)
   
   ### Recording User Set Parameters ###
   Rot <- rotation
@@ -71,7 +71,7 @@ OPC <- function(plyFile, rotation=0, minimum_faces=3, minimum_area=0) {
   params <- list(Degrees_Rotated= Rot, Minimum_Faces=MinFace, Minimum_Area=MinArea)
   
   
-  out <- list("Patch_Count"=patch_count, "Patch_Details"=patch_details, "plyFile"=plyFile, "Patches"=binned_patches, "Parameters"=params)
+  out <- list("Patch_Count"=patch_count, "Patch_Details"=patch_details., "plyFile"=plyFile, "Patches"=binned_patches, "Parameters"=params)
   BinSort <- out$Patch_Count$directions[order(row.names(out$Patch_Count$directions)),]
   cat("Total Number of Patches =", out$Patch_Count$'total patches')
   cat("\nNumber of Patches per Directional Bin =")
